/*
   Split hostname prefixed logfiles into separate files.

   David Phillips <david@acz.org>
*/

#include <stdio.h>
#include <map>
#include <string>
#include <vector>

const int MAX = 5000;

typedef std::vector<std::string> vstring;
typedef std::map<std::string, vstring> vsmap;

bool sfgets(FILE *fp, std::string &s)
{
   char buf[4096];
   int i, n;

   s.resize(0);
   for (;;)
   {
      if (fgets(buf, sizeof(buf), fp) == NULL)
         return (s.size() != 0);
      n = strlen(buf);
      i = n - 1;
      while ((i >= 0) && ((buf[i] == '\r') || (buf[i] == '\n')))
      {
         buf[i] = '\0';
         i--;
      }
      s += buf;
      if (i < (n - 1))
         break;
   }

   return true;
}

void dump(const vsmap &m)
{
   vsmap::const_iterator i;
   unsigned int j;
   FILE *fp;
   
   for (i = m.begin(); i != m.end(); i++)
   {
      fp = fopen(i->first.c_str(), "a");
      if (fp == NULL)
         return;
      for (j = 0; j < i->second.size(); j++)
         fprintf(fp, "%s\n", i->second[j].c_str());
      fclose(fp);
   }
}

void add(vsmap &m, const std::string &s)
{
   unsigned int i;

   for (i = 0; i < s.size(); i++)
      if (s[i] == ' ')
         break;
   if ((i == 0) || ((i + 1) >= s.size()))
      return;
   m[s.substr(0, i)].push_back(s.substr(i + 1, s.size() - i));
}

void split(FILE *fp)
{
   vsmap m;
   std::string s;
   int n;

   n = 0;
   for (;;)
   {
      if (!sfgets(fp, s))
         break;
      add(m, s);
      n++;
      if (n == MAX)
      {
         n = 0;
         dump(m);
         m.clear();
      }
   }
   dump(m);
}

int main(int argc, char *argv[])
{
   split(stdin);

   return 0;
}
